@@ -4,8 +4,8 @@ from aws_cdk import (
     aws_rds as _rds,
     aws_ec2 as _ec2,
     aws_kms as _kms,
-    # aws_route53 as route53,
-    # aws_route53_targets as route53_targets,
+    aws_route53 as route53,
+    aws_route53_targets as route53_targets,
 )
 from aws_cdk_constructs.utils import normalize_environment_parameter, get_version
 
@@ -94,6 +94,7 @@ class Database(Construct):
 
         cloudwatch_audit_log (str): Applicable only to Oracle instances. If to enable audit logs export in S3. The default is no log exports. Specify this param in case you want to have the audit log export enabled
 
+        dns_record: (Optional | str) The DNS record associated to the Database if multiple Databases
 
     """
     @property
@@ -169,6 +170,7 @@ class Database(Construct):
         s3_import_buckets=None,
         rubrik_backup="True",
         cloudwatch_audit_log=None,
+        dns_record=None,
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -365,18 +367,24 @@ class Database(Construct):
             self._cluster.add_rotation_single_user(
                 automatically_after= cdk.Duration.days(30)
             )
-            
-            # Create DNS record
-            # hosted_zone_id = aws_account["route53_hosted_zone_id"]
-            # domain_name = aws_account["route53_domain_name"]
-            # dns_record = app_name if app_name else dns_record
-            # route53_zone = route53.PrivateHostedZone.from_hosted_zone_attributes(self, f"RDSPrivateHostedZone{dns_record}", hosted_zone_id=hosted_zone_id, zone_name=domain_name)
-            # route53.ARecord(self, 
-            #     f"RDSAliasRecord{dns_record}",
-            #     zone=route53_zone,
-            #     target=cdk.Token.as_string(self._cluster.cluster_endpoint), # << Not working here
-            #     record_name=f"{app_name}.{domain_name}"
-            # )
+            if not is_production:
+                # Create DNS record
+                cluster_hostname=str(self._cluster.cluster_endpoint.hostname)
+                cluster_hostname = ''.join(cluster_hostname.split())
+
+                hosted_zone_id = aws_account["route53_hosted_zone_id"]
+                domain_name = aws_account["route53_domain_name"]
+
+                dns_record = 'db.'+app_name if app_name else dns_record
+                route53_zone = route53.PrivateHostedZone.from_hosted_zone_attributes(self, f"RDSPrivateHostedZone{dns_record}", hosted_zone_id=hosted_zone_id, zone_name=domain_name)
+                route53.CnameRecord(self,
+                    f"RDSAliasRecord{dns_record}",
+                    zone=route53_zone,
+                    #target=cdk.Token.as_string(self._cluster.cluster_endpoint), # << Not working here
+                    #target=route53.RecordTarget.from_values(self._cluster.cluster_endpoint.hostname),
+                    domain_name=cluster_hostname,
+                    record_name=f"{dns_record}.{domain_name}"
+                )
 
             # Conditionally create a cluster from a snapshot
             if use_snapshot:
@@ -490,6 +498,25 @@ class Database(Construct):
                 automatically_after= cdk.Duration.days(30)
             )
 
+
+            # Create DNS record
+            if not is_production:
+                instance_hostname=str(self._instance.instance_endpoint.hostname)
+                instance_hostname = ''.join(instance_hostname.split())
+
+
+                hosted_zone_id = aws_account["route53_hosted_zone_id"]
+                domain_name = aws_account["route53_domain_name"]
+
+                dns_record = 'db.'+app_name if app_name else dns_record
+                route53_zone = route53.PrivateHostedZone.from_hosted_zone_attributes(self, f"RDSPrivateHostedZone{dns_record}", hosted_zone_id=hosted_zone_id, zone_name=domain_name)
+                route53.CnameRecord(self,
+                    f"RDSAliasRecord{dns_record}",
+                    zone=route53_zone,
+                    domain_name=instance_hostname,
+                    record_name=f"{dns_record}.{domain_name}"
+                )
+
             # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
 
             if to_be_backed_up:
